@@ -1,5 +1,8 @@
+import importlib
 import unittest
 
+import testcase.app.app_constants
+from worker.framework import constants
 from worker.test import AppTestRun
 from worker import API
 from worker.test.lambda_function_test_run import generate_parser
@@ -10,6 +13,8 @@ class TestLambdaApp(unittest.TestCase):
 
     def test_lambda_app(self):
         asset_id = 3083
+        importlib.reload(constants)
+        importlib.reload(testcase.app.app_constants)
 
         def run():
             collections = ['drilling-efficiency.mse']
@@ -20,7 +25,8 @@ class TestLambdaApp(unittest.TestCase):
                 '--start_timestamp', '1502041854',
                 '--end_timestamp', '1502043349',
                 '--timestep', '600',
-                '--to_delete', str(True)
+                '--to_delete', str(True),
+                '--storage_type', str('mongo')
             ])
 
             app = AppTestRun(app_lambda.lambda_handler, collections, args=args)
