@@ -2,28 +2,35 @@ import json
 import time
 
 from worker.app.modules.time_activity_module import TimeActivityModule
-from worker.framework import constants
 from worker.data.operations import gather_data_for_period
-from worker.framework.mixins import RedisMixin, LoggingMixin, RollbarMixin
-from worker.framework.state import State
+from worker.framework import constants
+from worker.mixins.logging import LoggingMixin
+from worker.mixins.rollbar import RollbarMixin
+from worker.state.mixins import StateMixin
+from worker.state.state import State
 from worker import exceptions
 
 
-class App(RedisMixin, LoggingMixin, RollbarMixin):
+class App(StateMixin, LoggingMixin, RollbarMixin):
     app_state_fields = {
         'asset_id': int,
         'last_processed_timestamp': int
     }
 
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+        self.app_key = constants.get('global.app-key')
+        self.app_name = constants.get('global.app-name')
+        self.module_key = None
+
+        state_storage_type = constants.get("global.state_storage_type", None)
+        if state_storage_type is not None:
+            # Add to kwargs if defined in constants, else will get from environment
+            kwargs["state_storage_type"] = state_storage_type
 
         self.asset_id = None
         self.event = None
-        self.state = None
 
-        self.app_name = constants.get('global.app-name')
-        self.app_key = constants.get('global.app-key')
+        super().__init__(*args, **kwargs)
 
     def load(self, event: str):
         """
@@ -210,16 +217,8 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         except Exception:
             raise Exception('Event does not contain asset_id: {}'.format(event))
 
-    def load_state(self):
-        try:
-            r = self.get_redis()
-            previous_state = r.get(self.get_redis_key(self.asset_id, self.app_key))
-            previous_state = json.loads(previous_state)
-        except Exception as ex:
-            self.error(self.asset_id, "REDIS connection error: {0}".format(ex))
-            previous_state = {
-                "asset_id": self.asset_id,
-            }
+    def load_state(self, state_key: [str, None] = None, auto_migrate: bool = False) -> dict:
+        previous_state = super().load_state(state_key=state_key, auto_migrate=auto_migrate)
 
         state = State(self.app_state_fields, previous_state)
 
@@ -228,9 +227,11 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
 
         return state
 
-    def save_state(self):
-        r = self.get_redis()
-        r.set(self.get_redis_key(self.asset_id, self.app_key), value=self.state.to_json())
+    def save_state(self, state_key: [str, None] = None, timestamp: [int, None] = None):
+        if not timestamp:
+            timestamp = self.state.get('last_processed_timestamp', 0)
+
+        super().save_state(state_key=state_key, timestamp=timestamp)
 
     def get_modules(self):
         raise exceptions.Misconfigured("No modules found")
@@ -248,7 +249,8 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
             try:
                 module.run(self.event)
             except Exception:
-                self.track_error(message=f"Error in module {module_type.module_key}")
+                message = f"Error in module {module_type.module_key}"
+                self.track_error(message=message)
 
         last_processed_timestamp = self.event[-1].get('timestamp')
         self.state['last_processed_timestamp'] = last_processed_timestamp
